En esta página

zabbix_sender

ZABBIX_SENDER(1)            Manual de comandos generales           ZABBIX_SENDER(1)

NOMBRE
       zabbix_sender - utilidad de envío de Zabbix

SINOPSIS
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host -k key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect cert --tls-ca-file CA-file [--tls-crl-file CRL-file]
       [--tls-server-cert-issuer cert-issuer] [--tls-server-cert-subject
       cert-subject] --tls-cert-file cert-file --tls-key-file key-file
       [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k key -o
       value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect cert --tls-ca-file CA-file [--tls-crl-file
       CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect cert --tls-ca-file CA-file
       [--tls-crl-file CRL-file] [--tls-server-cert-issuer cert-issuer]
       [--tls-server-cert-subject cert-subject] --tls-cert-file cert-file
       --tls-key-file key-file [--tls-cipher13 cipher-string] [--tls-cipher
       cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] -s
       host --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string] -k
       key -o value
       zabbix_sender [-v] -z server [-p port] [-I IP-address] [-t timeout] [-s
       host] --tls-connect psk --tls-psk-identity PSK-identity --tls-psk-file
       PSK-file [--tls-cipher13 cipher-string] [--tls-cipher cipher-string]
       [-T] [-N] [-r] -i input-file
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] -k key -o value
       zabbix_sender [-v] -c config-file [-z server] [-p port] [-I IP-address]
       [-t timeout] [-s host] --tls-connect psk --tls-psk-identity PSK-iden‐
       tity --tls-psk-file PSK-file [--tls-cipher13 cipher-string] [--tls-ci‐
       pher cipher-string] [-T] [-N] [-r] -i input-file
       zabbix_sender -h
       zabbix_sender -V

DESCRIPCIÓN
       zabbix_sender es una utilidad de línea de comandos para enviar datos de
       monitorización al server o proxy de Zabbix. En el server de Zabbix debe
       crearse un item de tipo Zabbix trapper con la clave correspondiente.
       Tenga en cuenta que los valores entrantes solo se aceptarán de los hosts
       especificados en el campo Allowed hosts de este item.

OPCIONES
       -c, --config config-file
              Utiliza config-file. zabbix_sender lee los detalles del server
              del archivo de configuración de agentd. De forma predeterminada,
              zabbix_sender no lee ningún archivo de configuración. Solo se
              admiten los parámetros Hostname, ServerActive, SourceIP,
              TLSConnect, TLSCAFile, TLSCRLFile, TLSServerCertIssuer,
              TLSServerCertSubject, TLSCertFile, TLSKeyFile, TLSPSKIdentity y
              TLSPSKFile. El Hostname definido mediante el parámetro
              HostnameItem no se utilizará; en este caso, el nombre del host
              debe especificarse mediante la línea de comandos (consulte la
              opción -s). Todas las direcciones definidas en el parámetro de
              configuración ServerActive del agent se utilizan para enviar
              datos. Si el envío de datos por lotes falla en una dirección, los
              lotes siguientes no se enviarán a esa dirección.

       -z, --zabbix-server server
              Nombre de host o dirección IP del server de Zabbix. Si un host
              está monitorizado por un proxy, debe utilizarse el nombre de host
              o la dirección IP del proxy. Cuando se utiliza junto con
              --config, reemplaza las entradas del parámetro ServerActive
              especificadas en el archivo de configuración de agentd.

       -p, --port port
              Especifica el número de puerto en el que se ejecuta el trapper del
              server de Zabbix. El valor predeterminado es 10051. Cuando se
              utiliza junto con --config, reemplaza las entradas de puerto del
              parámetro ServerActive especificadas en el archivo de
              configuración de agentd.

       -I, --source-address IP-address
              Especifica la dirección IP de origen. Cuando se utiliza junto con
              --config, reemplaza el parámetro SourceIP especificado en el
              archivo de configuración de agentd.

       -t, --timeout seconds
              Especifica el tiempo de espera. Rango válido: 1-300 segundos
              (predeterminado: 60)

       -s, --host host
              Especifica el nombre del host al que pertenece el item (tal como
              está registrado en el frontend de Zabbix). La dirección IP y el
              nombre DNS del host no funcionarán. Cuando se utiliza junto con
              --config, reemplaza el parámetro Hostname especificado en el
              archivo de configuración de agentd.

       -k, --key key
              Especifica la clave del item al que se enviará el valor.

       -o, --value value
              Especifica el valor del item.

       -i, --input-file input-file
              Carga los valores desde el archivo de entrada. Especifique - como
              <input-file> para leer los valores desde la entrada estándar.
              Cada línea del archivo contiene, separados por espacios en blanco:
              <hostname> <key> <value>. Cada valor debe especificarse en su
              propia línea. Cada línea debe contener 3 entradas separadas por
              espacios en blanco: <hostname> <key> <value>, donde "hostname"
              es el nombre del host monitorizado tal como está registrado en el
              frontend de Zabbix, "key" es la clave del item de destino y
              "value" es el valor que se enviará. Especifique - como
              <hostname> para utilizar el nombre de host del archivo de
              configuración del agent o del argumento --host.

              Un ejemplo de línea de un archivo de entrada:

               "Linux DB3" db.connections 43

              El tipo de valor debe estar configurado correctamente en la
              configuración del item del frontend de Zabbix. zabbix_sender
              enviará hasta 250 valores en una conexión. El contenido del
              archivo de entrada debe estar codificado en UTF-8. Todos los
              valores del archivo de entrada se envían en orden secuencial, de
              arriba abajo. Las entradas deben tener el siguiente formato:

                     • Se admiten entradas entre comillas y sin comillas.

                     • Las comillas dobles son el carácter de delimitación.

                     • Las entradas que contienen espacios en blanco deben estar
                       entre comillas.

                     • Las comillas dobles y las barras invertidas dentro de
                       una entrada entre comillas deben escaparse con una barra
                       invertida.

                     • No se admite el escape en entradas sin comillas.

                     • Las secuencias de escape de salto de línea (\n) se
                       admiten en cadenas entre comillas.

                     • Las secuencias de escape de salto de línea se eliminan
                       del final de una entrada.

       -T, --with-timestamps
              Esta opción solo puede utilizarse con la opción --input-file.

              Cada línea del archivo de entrada debe contener 4 entradas
              separadas por espacios en blanco: <hostname> <key> <timestamp>
              <value>. La marca de tiempo debe especificarse en formato de marca
              de tiempo Unix. Si el item de destino tiene triggers que hacen
              referencia a él, todas las marcas de tiempo deben estar en orden
              creciente; de lo contrario, el cálculo de eventos no será
              correcto.

              Un ejemplo de línea de un archivo de entrada:

               "Linux DB3" db.connections 1429533600 43

              Para obtener más información, consulte la opción --input-file.

              Si se envía un valor con marca de tiempo para un host que se
              encuentra en un mantenimiento de tipo “no data”, este valor se
              descartará; sin embargo, es posible enviar un valor con marca de
              tiempo correspondiente a un período de mantenimiento expirado y
              este será aceptado.

       -N, --with-ns
              Esta opción solo puede utilizarse con la opción
              --with-timestamps.

              Cada línea del archivo de entrada debe contener 5 entradas
              separadas por espacios en blanco: <hostname> <key> <timestamp>
              <ns> <value>.

              Un ejemplo de línea de un archivo de entrada:

               "Linux DB3" db.connections 1429533600 7402561 43

              Para obtener más información, consulte la opción --input-file.

       -r, --real-time
              Envía los valores uno por uno tan pronto como se reciben. Esto
              puede utilizarse al leer desde la entrada estándar.

       --tls-connect value
              Cómo conectarse al server o proxy. Valores:

                   unencrypted
                               conectarse sin cifrado (predeterminado)

                   psk         conectarse mediante TLS y una clave precompartida

                   cert        conectarse mediante TLS y un certificado

       --tls-ca-file CA-file
              Ruta completa de un archivo que contiene los certificados de la
              CA de nivel superior para la verificación del certificado del
              par.

       --tls-crl-file CRL-file
              Ruta completa de un archivo que contiene certificados revocados.

       --tls-server-cert-issuer cert-issuer
              Emisor de certificado del server permitido.

       --tls-server-cert-subject cert-subject
              Sujeto del certificado del server permitido.

       --tls-cert-file cert-file
              Ruta completa de un archivo que contiene el certificado o la
              cadena de certificados.

       --tls-key-file key-file
              Ruta completa de un archivo que contiene la clave privada.

       --tls-psk-identity PSK-identity
              Cadena de identidad PSK.

       --tls-psk-file PSK-file
              Ruta completa de un archivo que contiene la clave precompartida.

       --tls-cipher13 cipher-string
              Cadena de cifrado para OpenSSL 1.1.1 o posterior para TLS 1.3.
              Reemplaza los criterios de selección predeterminados del conjunto
              de cifrado. Esta opción no está disponible si la versión de
              OpenSSL es anterior a 1.1.1.

       --tls-cipher cipher-string
              Cadena de prioridad de GnuTLS (para TLS 1.2 y posteriores) o
              cadena de cifrado de OpenSSL (solo para TLS 1.2). Reemplaza los
              criterios de selección predeterminados del conjunto de cifrado.

       -v, --verbose
              Modo detallado; utilice -vv para obtener más detalles.

       -h, --help
              Muestra esta ayuda y sale.

       -V, --version
              Muestra la información de versión y sale.

ESTADO DE SALIDA
       El estado de salida es 0 si los valores se enviaron y todos fueron
       procesados correctamente por el server. Si se enviaron datos, pero el
       procesamiento de al menos uno de los valores falló, el estado de salida
       es 2. Si falló el envío de datos, el estado de salida es 1.

EJEMPLOS
       zabbix_sender -c  /etc/zabbix/zabbix_agentd.conf  -k  mysql.queries  -o
       342.45
              Envía 342.45 como valor del item mysql.queries del host
              monitorizado. Utiliza el host monitorizado y el server de Zabbix
              definidos en el archivo de configuración del agent.

       zabbix_sender -c /etc/zabbix/zabbix_agentd.conf -s "Monitored Host"  -k
       mysql.queries -o 342.45
              Envía 342.45 como valor del item mysql.queries del host Monitored
              Host utilizando el server de Zabbix definido en el archivo de
              configuración del agent.

       zabbix_sender -z 192.168.1.113 -i data_values.txt
              Envía los valores del archivo data_values.txt al server de Zabbix
              con la IP 192.168.1.113. Los nombres de host y las claves están
              definidos en el archivo.

       echo "- hw.serial.number  1287872261  SQ4321ASDF"  |  zabbix_sender  -c
       /usr/local/etc/zabbix_agentd.conf -T -i -
              Envía un valor con marca de tiempo desde la línea de comandos al
              server de Zabbix especificado en el archivo de configuración del
              agent. El guion en los datos de entrada indica que también debe
              utilizarse el nombre de host del mismo archivo de configuración.

       echo '"Zabbix server" trapper.item ""' | zabbix_sender -z 192.168.1.113
       -p 10000 -i -
              Envía un valor vacío de un item al server de Zabbix con dirección
              IP 192.168.1.113 en el puerto 10000 desde la línea de comandos.
              Los valores vacíos deben indicarse mediante comillas dobles
              vacías.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  cert  --tls-ca-file  /home/zabbix/zabbix_ca_file
       --tls-cert-file      /home/zabbix/zabbix_agentd.crt      --tls-key-file
       /home/zabbix/zabbix_agentd.key
              Envía 342.45 como valor del item mysql.queries del host Monitored
              Host al server con IP 192.168.1.113 mediante TLS con certificado.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  psk  --tls-psk-identity  "PSK  ID Zabbix agentd"
       --tls-psk-file /home/zabbix/zabbix_agentd.psk
              Envía 342.45 como valor del item mysql.queries del host Monitored
              Host al server con IP 192.168.1.113 mediante TLS con una clave
              precompartida (PSK).

VÉASE TAMBIÉN
       Documentación

       zabbix_agentd(8),  zabbix_get(1),  zabbix_proxy(8),   zabbix_server(8),
       zabbix_js(1), zabbix_agent2(8), zabbix_web_service(8)

Zabbix                            2022-01-06                  ZABBIX_SENDER(1)